@@ -24,7 +24,7 @@
 """
 
 # standard library import
-from os import  getpid
+from os import getpid
 from socket import getfqdn
 
 # third parties components
@@ -41,7 +41,7 @@ class Uniq(Plugin):
 
     def __init__(self, daemon):
         Plugin.__init__(self, daemon)
-        self.chan = 'mpd_sima:{0}.{1}'.format(getfqdn(), getpid())
+        self.chan = None
         self.channels = []
         self._registred = False
 
@@ -70,6 +70,7 @@ class Uniq(Plugin):
             self.log.warning(' '.join(channels))
 
     def sub_chan(self):
+        self.chan = f'mpd_sima:{getfqdn()}.{getpid()}'
         self.log.debug('Registering as %s', self.chan)
         try:
             self.player.subscribe(self.chan)
